@@ -28,7 +28,7 @@ class TestDataBuilderTest(object):
     def test_username(self):
         self.config_parser.get.return_value = '<username>'
 
-        result = self.uut.store_username
+        result = self.uut.service_username
 
         self.config_parser.get.assert_called_once_with('store', 'username')
         assert_that(result).is_equal_to('<username>')
@@ -36,7 +36,7 @@ class TestDataBuilderTest(object):
     def test_password(self):
         self.config_parser.get.return_value = '<password>'
 
-        result = self.uut.store_password
+        result = self.uut.service_password
 
         self.config_parser.get.assert_called_once_with('store', 'password')
         assert_that(result).is_equal_to('<password>')
@@ -44,7 +44,7 @@ class TestDataBuilderTest(object):
     def test_store_name(self):
         self.config_parser.get.return_value = '<store_name>'
 
-        result = self.uut.store_name
+        result = self.uut.service_name
 
         self.config_parser.get.assert_called_once_with('store', 'name')
         assert_that(result).is_equal_to('<store_name>')
@@ -52,14 +52,14 @@ class TestDataBuilderTest(object):
     def test_store_host(self):
         self.config_parser.get.return_value = '<store_host>'
 
-        result = self.uut.store_host
+        result = self.uut.service_host
 
         self.config_parser.get.assert_called_once_with('store', 'host')
         assert_that(result).is_equal_to('<store_host>')
 
     def test_store_port(self):
         self.config_parser.get.return_value = '5'
-        result = self.uut.store_port
+        result = self.uut.service_port
 
         self.config_parser.get.assert_called_once_with('store', 'port')
         assert_that(result).is_equal_to(5)
